'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkInput = checkInput;
exports.default = pptx2pdf;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('mz/fs');

var _fs2 = _interopRequireDefault(_fs);

var _child_process = require('mz/child_process');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function checkInput(inputPath) {
  return new Promise(function (resolve, reject) {

    var ext = _path2.default.extname(inputPath);

    var extensions = ['.pdf', '.pptx', '.ppt', '.odp'];

    if (extensions.includes(ext)) return resolve(ext);else return reject('Input file extension must be .pptx, .ppt, .odp and .pdf');
  });
}

function pptx2pdf(_ref) {
  var input = _ref.input,
      outputDir = _ref.outputDir,
      filename = _ref.filename,
      target = _ref.target,
      png = _ref.png,
      removePdf = _ref.removePdf,
      libreofficeBin = _ref.libreofficeBin,
      convertBin = _ref.convertBin;


  var defaultLibreoffice = process.platform === 'darwin' ? '/Applications/LibreOffice.app/Contents/MacOS/soffice' : '/usr/bin/libreoffice';

  var libreoffice = libreofficeBin || defaultLibreoffice;

  var convert = 'convert';

  var inputPath = input || target;
  var baseFilename = _path2.default.basename(inputPath);
  var ext = baseFilename.split('.').pop();
  var outputFile = filename || baseFilename.replace(new RegExp('.' + ext + '$'), '.pdf');
  var outputPng = outputFile.replace(/\.pdf$/, '.png');
  var outputPath = outputDir + '/' + outputFile;
  var cmdPdf = libreoffice + ' --headless --invisible --convert-to pdf --outdir ' + outputDir + ' ' + inputPath;
  var cmdPng = convert + ' -limit memory 0 -limit map 0 -resize 1200 -density 200  ' + outputPath + ' ' + outputPath.replace(/\.pdf$/, '') + '.png';
  var cmdPdf2Png = convert + ' -limit memory 0 -limit map 0 -resize 1200 -density 200  ' + inputPath + ' ' + outputDir + '/' + outputPng;

  return _fs2.default.access(inputPath).then(function () {
    return checkInput(inputPath);
  }).then(function (ext) {

    if (ext === '.pdf') return (0, _child_process.exec)(cmdPdf2Png);

    return (0, _child_process.exec)(cmdPdf).then(function () {
      if (!png) {
        return _fs2.default.access(outputPath);
      } else {
        return (0, _child_process.exec)(cmdPng).then(function () {
          if (removePdf) _fs2.default.unlink(outputPath);
        });
      }
    });
  });
}